﻿using System;
using System.Web.UI;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.WebEdition;

public partial class _Default : System.Web.UI.Page 
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (!Page.IsPostBack)
        {
            Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
            Map1.MapUnit = GeographyUnit.DecimalDegree;
            Map1.MapTools.MouseCoordinate.Enabled = true;

            ShapeFileFeatureLayer statesLayer = new ShapeFileFeatureLayer(MapPath("~/app_data/states.shp"));
            statesLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(255, 243, 239, 228), GeoColor.FromArgb(255, 218, 193, 163), 1);
            statesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            Map1.StaticOverlay.Layers.Add(statesLayer);

            ShapeFileFeatureLayer shapesLayer = new ShapeFileFeatureLayer(MapPath("~/app_data/lineshape.shp"));
            shapesLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Highway1;
            shapesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            Map1.DynamicOverlay.Layers.Add("Shapes", shapesLayer);

            shapesLayer.Open();
            Map1.CurrentExtent = shapesLayer.GetBoundingBox();
            shapesLayer.Close();
        }
    }

    public void SaveShapes(object sender, EventArgs e)
    {
        if (!Map1.DynamicOverlay.Layers["Shapes"].IsVisible)
        {
            ShapeFileFeatureLayer shapesLayer = new ShapeFileFeatureLayer(MapPath("~/app_data/lineshape.shp"), ShapeFileReadWriteMode.ReadWrite);
            shapesLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.Highway1;
            shapesLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            shapesLayer.Open();
            shapesLayer.EditTools.BeginTransaction();
            Collection<Feature> features = Map1.EditOverlay.Features;
            foreach (Feature feature in features)
            {
                shapesLayer.EditTools.Update(feature);
            }
            shapesLayer.EditTools.CommitTransaction();
            shapesLayer.Close();

            Map1.EditOverlay.Features.Clear();
            Map1.EditOverlay.TrackMode = TrackMode.None;
            Map1.DynamicOverlay.Layers["Shapes"].IsVisible = true;
            Map1.DynamicOverlay.Redraw();
        }
    }

    public void EditShapes(object sender, EventArgs e)
    {
        if (Map1.DynamicOverlay.Layers["Shapes"].IsVisible)
        {
            ShapeFileFeatureLayer shapesLayer = (ShapeFileFeatureLayer)Map1.DynamicOverlay.Layers["Shapes"];

            shapesLayer.Open();
            Collection<Feature> features = shapesLayer.QueryTools.GetAllFeatures(ReturningColumnsType.AllColumns);
            shapesLayer.Close();

            Map1.EditOverlay.Features.Clear();
            foreach (Feature feature in features)
            {
                Map1.EditOverlay.Features.Add(feature);
            }

            Map1.DynamicOverlay.Layers["Shapes"].IsVisible = false;

            Map1.EditOverlay.TrackMode = TrackMode.Edit;
            Map1.EditOverlay.EditSettings.IsReshapable = true;
            Map1.EditOverlay.EditSettings.IsDraggable = false;
            Map1.EditOverlay.EditSettings.IsResizable = false;
            Map1.EditOverlay.EditSettings.IsRotatable = false;
        }
    }
}
